markuptools.MusicGlyph
======================

.. abjad-lineage:: abjad.tools.markuptools.MusicGlyph.MusicGlyph.MusicGlyph

.. autoclass:: abjad.tools.markuptools.MusicGlyph.MusicGlyph.MusicGlyph
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.markuptools.MusicGlyph.MusicGlyph.MusicGlyph.args
   :noindex:

.. autoattribute:: abjad.tools.markuptools.MusicGlyph.MusicGlyph.MusicGlyph.command
   :noindex:

.. autoattribute:: abjad.tools.markuptools.MusicGlyph.MusicGlyph.MusicGlyph.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.markuptools.MusicGlyph.MusicGlyph.MusicGlyph.storage_format
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.markuptools.MusicGlyph.MusicGlyph.MusicGlyph.__eq__
   :noindex:

.. automethod:: abjad.tools.markuptools.MusicGlyph.MusicGlyph.MusicGlyph.__ge__
   :noindex:

.. automethod:: abjad.tools.markuptools.MusicGlyph.MusicGlyph.MusicGlyph.__gt__
   :noindex:

.. automethod:: abjad.tools.markuptools.MusicGlyph.MusicGlyph.MusicGlyph.__le__
   :noindex:

.. automethod:: abjad.tools.markuptools.MusicGlyph.MusicGlyph.MusicGlyph.__lt__
   :noindex:

.. automethod:: abjad.tools.markuptools.MusicGlyph.MusicGlyph.MusicGlyph.__ne__
   :noindex:

.. automethod:: abjad.tools.markuptools.MusicGlyph.MusicGlyph.MusicGlyph.__repr__
   :noindex:

.. automethod:: abjad.tools.markuptools.MusicGlyph.MusicGlyph.MusicGlyph.__str__
   :noindex:
